@@ -5,6 +5,7 @@ from typing import Union
 from urllib.parse import quote
 from urllib.parse import unquote_to_bytes
 
+import redis
 from django.contrib import admin
 from django.http import HttpResponseForbidden
 from django.http import HttpResponseNotFound
@@ -25,13 +26,13 @@ logger = getLogger(__name__)
 def cleanup_changelist_response(response: TemplateResponse):
     obj: RedisServer
     for obj in response.context_data['cl'].queryset:
-        connection = obj.__dict__.get('connection')
-        if connection:
-            connection.close()
+        cleanup_connection(response, obj)
 
 
-def cleanup_connection(response: TemplateResponse, connection):
-    connection.close()
+def cleanup_connection(_, server: RedisServer):
+    connection = server.__dict__.get('connection')
+    if connection:
+        connection.close()
 
 
 class RedisServerAdmin(admin.ModelAdmin):
@@ -89,9 +90,11 @@ class RedisServerAdmin(admin.ModelAdmin):
 
     def tools(self, obj: RedisServer):
         return format_html(
-            '<a href="{}">{}</a>',
+            '<a href="{}">{}</a><br><a href="{}">{}</a>',
             resolve_url('admin:redisboard_redisserver_inspect', server_id=obj.id),
             _('Inspect'),
+            resolve_url('admin:redisboard_redisserver_details', server_id=obj.id),
+            _('Details'),
         )
 
     tools.short_description = _('Tools')
@@ -112,53 +115,57 @@ class RedisServerAdmin(admin.ModelAdmin):
             def wrapper(request, server_id, **kwargs):
                 server = get_object_or_404(RedisServer, id=server_id)
                 if self.has_view_permission(request, server) and request.user.has_perm('redisboard.can_inspect'):
-                    connection = server.connection
                     try:
                         response = view(request, server, **kwargs)
                         if isinstance(response, TemplateResponse):
-                            response.add_post_render_callback(partial(cleanup_connection, connection=connection.close))
+                            response.add_post_render_callback(partial(cleanup_connection, server=server))
                         return response
                     finally:
-                        connection.close()
+                        cleanup_connection(None, server)
                 else:
                     return HttpResponseForbidden("You can't inspect this server.")
 
             return wrapper
 
         return [
+            path(
+                '<int:server_id>/details/',
+                wrap(self.details_view),
+                name='redisboard_redisserver_details',
+            ),
             path(
                 '<int:server_id>/inspect/',
-                wrap(self.inspect),
+                wrap(self.inspect_view),
                 name='redisboard_redisserver_inspect',
             ),
             path(
                 '<int:server_id>/inspect/<int:db>/',
-                wrap(self.inspect),
+                wrap(self.inspect_view),
                 name='redisboard_redisserver_inspect',
             ),
             path(
                 '<int:server_id>/inspect/<int:db>/key/<path:key>/',
-                wrap(self.inspect_key),
+                wrap(self.inspect_key_view),
                 name='redisboard_redisserver_inspect',
             ),
             path(
                 '<int:server_id>/inspect/<int:db>/<int:cursor>/',
-                wrap(self.inspect),
+                wrap(self.inspect_view),
                 name='redisboard_redisserver_inspect',
             ),
             path(
                 '<int:server_id>/inspect/<int:db>/<int:cursor>/key/<path:key>/',
-                wrap(self.inspect_key),
+                wrap(self.inspect_key_view),
                 name='redisboard_redisserver_inspect',
             ),
             path(
                 '<int:server_id>/inspect/<int:db>/<int:cursor>/<int:count>/key/<path:key>/',
-                wrap(self.inspect_key),
+                wrap(self.inspect_key_view),
                 name='redisboard_redisserver_inspect',
             ),
         ] + urlpatterns
 
-    def inspect_key(self, request, server: RedisServer, db: int, key: str, cursor: int = 0, count: int = 0):
+    def inspect_key_view(self, request, server: RedisServer, db: int, key: str, cursor: int = 0, count: int = 0):
         key: bytes = unquote_to_bytes(key)
         display = server.display
         if not server.connection.exists(key):
@@ -181,11 +188,11 @@ class RedisServerAdmin(admin.ModelAdmin):
                 },
                 'original': server,
                 'opts': {'app_label': 'redisboard', 'object_name': 'redisserver'},
-                'media': '',
+                'media': self.media,
             },
         )
 
-    def inspect(self, request, server: RedisServer, db: Union[int, None] = None, cursor: Union[int, None] = 0):
+    def inspect_view(self, request, server: RedisServer, db: Union[int, None] = None, cursor: Union[int, None] = 0):
         stats = server.stats
         active = None
         databases = []
@@ -218,7 +225,49 @@ class RedisServerAdmin(admin.ModelAdmin):
                 'active': active,
                 'filters': f'?{request.GET.urlencode()}' if request.GET else '',
                 'opts': {'app_label': 'redisboard', 'object_name': 'redisserver'},
-                'media': '',
+                'media': self.media,
+            },
+        )
+
+    def details_view(self, request, server: RedisServer):
+        sections = {}
+        try:
+            conn = server.connection
+            conn.ping()
+            status = 'UP'
+        except (redis.exceptions.ConnectionError, redis.exceptions.TimeoutError) as exc:
+            status = f'DOWN: {exc}'
+        except redis.exceptions.RedisError as exc:
+            status = f'ERROR: {exc!r}'
+        else:
+            for section in [
+                'server',
+                'clients',
+                'memory',
+                'persistence',
+                'stats',
+                'replication',
+                'cpu',
+                'commandstats',
+                'latencystats',
+                'cluster',
+                'modules',
+                'keyspace',
+                'modules',
+                'errorstats',
+            ]:
+                sections[section] = conn.info(section)
+
+        return render(
+            request,
+            'redisboard/details.html',
+            {
+                **self.admin_site.each_context(request),
+                'original': server,
+                'sections': sections,
+                'status': status,
+                'opts': {'app_label': 'redisboard', 'object_name': 'redisserver'},
+                'media': self.media,
             },
         )
 
